import xarray as xr
import matplotlib.pyplot as plt
import numpy as np
from cartopy.feature import ShapelyFeature
import cartopy.crs as ccrs
import cartopy.feature as cfeature
from cartopy.mpl.gridliner import LONGITUDE_FORMATTER, LATITUDE_FORMATTER
from matplotlib import cm
import numpy as np
import cmocean.cm as cmo
from matplotlib.colors import ListedColormap
import matplotlib.colors as colors
import string

def plotDiff(lon,lat,diff,i,j):

    f, ax = plt.subplots(nrows=2, ncols=1,figsize=(12, 8), subplot_kw=dict(projection=ccrs.SouthPolarStereo(central_longitude=-55)),dpi=150)
    ax.add_feature(cfeature.LAND, color='lightgray', facecolor='0.9') #Grayscale colors can be set using 0 (black) to 1 (white)
    ax.add_feature(cfeature.COASTLINE, linewidth=0.75, zorder=10)

    plotdiff = plt.contourf(lon,lat,diff,levels=np.arange(-2.,2.25,0.0625),cmap=cmap_diff,transform=ccrs.PlateCarree(),extend = 'max') #zorder=10
    cbar = plt.colorbar(plotdiff,ax=ax,cmap=cmap_diff,pad=0.01, shrink=0.70, aspect=50,ticks=np.arange(-2.,2.25,0.25))
    cbar.set_label('Significant Wave Height (m)')
    ax.set_title(' Diference (Exp. '+str(case)+' - CTRL)',verticalalignment='center', horizontalalignment='center', color="black",size= 10, weight='bold')
    grid = ax[i,j].gridlines(crs=ccrs.PlateCarree(), draw_labels=True,linewidth=0.5, color='gray', alpha=0.75)#, linestyle='--')
    grid.top_labels = False
    #grid.ylabels_right = False
    grid.xlines = False
    grid.ylines = False
    grid.xformatter = LONGITUDE_FORMATTER
    grid.yformatter = LATITUDE_FORMATTER
    grid.xlabel_style = {'size': 10, 'color': 'black'}
    grid.ylabel_style = {'size': 10, 'color': 'black'}
    ax.gridlines()

    return 


color_map_jet = cm.get_cmap('cubehelix_r')
cmap_diff = ListedColormap(color_map_jet(np.linspace(0.,0.75,32)))
#cmap_diff=cmo.dense

path1='/Users/jtakeo/Dropbox (CMCC)/projects/dayanisThesis/article1/data/model/mean/sat_veraomean.nc'
ds1 = xr.open_dataset(path1).sel(lat=slice(-78.875, -50.),lon=slice(260, 350))

f, ax = plt.subplots(3,3,figsize=(18, 12), gridspec_kw={'height_ratios': [1,1,1]},subplot_kw=dict(projection=ccrs.SouthPolarStereo(central_longitude=-55)),dpi=300)
#f.subplots_adjust(hspace = 0.85, wspace=0.001)
ax = ax.ravel()
#ax[-1].axis('off')
#figitem=['a','b','c','d','e','f','g']
figitem=string.ascii_lowercase

for i, case in enumerate(("ctrl","is1", "is2", "ic1", "ic2", "ic2_turb","ic2_is2","ic2_is2_turb","ic5")):

    path2='/Users/jtakeo/Dropbox (CMCC)/projects/dayanisThesis/article1/data/model/mean/'+str(case)+'_veraomean.nc'
    ds2 = xr.open_dataset(path2).sel(latitude=slice(-78.875, -50.),longitude=slice(260, 350))
    lon=ds2['longitude']
    lat=ds2['latitude']
    rmse =  np.squeeze(np.sqrt(((ds2['hs'].values - ds1['hs'].values) ** 2)))
    
    

    ptdiff=ax[i].contourf(lon,lat,rmse,levels=np.arange(0.,2.125,0.125),cmap=cmap_diff,transform=ccrs.PlateCarree(),extend = 'max')

    grid = ax[i].gridlines(crs=ccrs.PlateCarree(), draw_labels=True,linewidth=0.5, color='gray', alpha=0.75)#, linestyle='--')
    grid.top_labels = False
    #grid.ylabels_right = False
    grid.xlines = False
    grid.ylines = False
    grid.xformatter = LONGITUDE_FORMATTER
    grid.yformatter = LATITUDE_FORMATTER
    grid.xlabel_style = {'size': 10, 'color': 'black'}
    grid.ylabel_style = {'size': 10, 'color': 'black'}
    ax[i].gridlines()
    ax[i].add_feature(cfeature.LAND, color='lightgray', facecolor='0.9') #Grayscale colors can be set using 0 (black) to 1 (white)
    ax[i].add_feature(cfeature.COASTLINE, linewidth=0.75, zorder=10)
    
    cbar = plt.colorbar(ptdiff,ax=ax[i],cmap=cmap_diff,pad=0.01, shrink=0.45, aspect=20,ticks=np.arange(0.,2.25,0.5))
    #cbar.set_label('Hs (m)',size=12)
    cbar.ax.set_title('        Hs (m)',size=12)
    #cbar.ax.tick_params(labelsize=14)
    #print(ax[i].get_ylim())
    ax[i].text(-3101270, 4251194,'('+figitem[i]+')', color='k',fontsize='14')
    ax[i].text(1901270, 4251194,''+str(case).upper()+'', color='b',fontsize='11')
    #print(ax[i].get_ylim())

plt.tight_layout()
plt.savefig('./figure4.png',dpi=300)


#plt.show()




